<?php

namespace App\Models;

use CodeIgniter\Model;

class Model_home extends Model
{

    public function tot_arsip()
    {
        return $this->db->table('tbl_arsip')->countAll();
    }

    public function tot_dep()
    {
        return $this->db->table('tbl_dep')->countAll();
    }

    public function tot_user()
    {
        return $this->db->table('tbl_user')->countAll();
    }
    public function tot_kategori()
    {
        return $this->db->table('tbl_kategori')->countAll();
    }
    public function tot_biodata()
    {
        return $this->db->table('tbl_biodata')->countAll();
    }
    public function tot_identitas()
    {
        return $this->db->table('tbl_identitas')->countAll();
    }
    public function tot_mengajar()
    {
        return $this->db->table('tbl_mengajar')->countAll();
    }
    public function tot_pelatihan()
    {
        return $this->db->table('tbl_pelatihan')->countAll();
    }
    public function tot_pendidikan()
    {
        return $this->db->table('tbl_pendidikan')->countAll();
    }
}
